@@ -4,7 +4,7 @@ from typing import List, Union
 
 import httpx
 
-from botoy import json, macro
+from botoy import macro
 from botoy.config import Config
 from botoy.log import logger
 
@@ -448,7 +448,7 @@ class AsyncAction:
     ) -> dict:
         """基础请求方法, 提供部分提示信息，出错返回空字典，其他返回服务端响应结果"""
         if params is not None:
-            params = params.update({'funcname': funcname})
+            params.update({'funcname': funcname})
         else:
             params = {'funcname': funcname}
 
