@@ -1,7 +1,6 @@
 # pylint: disable = too-many-instance-attributes, W0212,W0236,E1133
 import asyncio
 import copy
-import sys
 import traceback
 from typing import Callable
 
@@ -21,24 +20,23 @@ class AsyncBotoy(Botoy):
     def asyncRun(self, func: Callable, *args):
         self.pool.submit(func, *args)
 
-    async def close(self, status=0):
+    async def close(self):
         await self.socketio.disconnect()
         self.pool.shutdown(wait=False)
         self._exit = True
-        sys.exit(status)
 
     async def run(self):
         try:
             await self.socketio.connect(self.config.address, transports=['websocket'])
         except Exception:
             logger.error(traceback.format_exc())
-            await self.close(1)
+            await self.close()
         else:
             try:
                 await self.socketio.wait()
             finally:
                 print('bye~')
-                await self.close(0)
+                await self.close()
 
     ########################################################################
     # context distributor
