@@ -11,7 +11,7 @@ import click
 from .__version__ import __version__
 from .async_client import AsyncBotoy
 from .client import Botoy
-from .util import check_schema
+from .contrib import check_schema
 
 echo = click.echo
 
@@ -132,6 +132,13 @@ def init(name, qq, host, port):
         if not os.path.isdir('plugins'):
             os.makedirs('plugins')
 
+    if click.confirm('是否修改或生成.gitignore文件', default=False, show_default=True):
+        ignore = '\n'.join(
+            ['\n# Botoy', 'botoy.json', 'REMOVED_PLUGINS', 'botoy-cache']
+        )
+        with open('.gitignore', 'a' if os.path.exists('.gitignore') else 'w') as f:
+            f.write(ignore)
+
 
 @cli.command()
 @click.option('-n', '--name', prompt='插件名', required=True)
@@ -142,15 +149,17 @@ def add(name, friend, group, event):
     """创建插件"""
     here = pathlib.Path('.').absolute()
     if here.name != 'plugins':
-        if not os.path.isdir('plugins'):
-            sys.exit('插件目录plugins不存在')
         plugin_dir = here / 'plugins'
+        if not os.path.isdir('plugins'):
+            plugin_dir.mkdir()
+            echo('插件目录plugins不存在, 已自动创建')
     else:
         plugin_dir = here
 
-    plugin_path = plugin_dir / f'bot_{name}.py'
-    if os.path.exists(plugin_path):
-        sys.exit('该插件已使用，请换一个插件名')
+    plugin_path_file = plugin_dir / f'bot_{name}.py'
+    plugin_path_folder = plugin_dir / f'bot_{name}'
+    if plugin_path_file.exists() or plugin_path_folder.exists():
+        sys.exit('该插件名已被使用，请换一个插件名')
     if not any([friend, group, event]):
         friend = group = event = True
 
@@ -186,7 +195,17 @@ def add(name, friend, group, event):
                 """
             )
         )
-    with open(plugin_path, 'w', encoding='utf8') as f:
+
+    use_file = click.confirm(
+        '插件使用单文件还是文件夹形式, 默认选是表示单文件', default=True, show_default=True
+    )
+    if use_file:
+        write_file = plugin_path_file
+    else:
+        plugin_path_folder.mkdir()
+        write_file = plugin_path_folder / '__init__.py'
+
+    with open(write_file, 'w', encoding='utf8') as f:
         f.write('from botoy import {}'.format(', '.join(imports)))
         f.write('\n\n')
         f.write('\n'.join(receivers))
