@@ -6,9 +6,9 @@ import sys
 
 from .action import Action
 from .collection import MsgTypes
+from .contrib import file_to_base64
 from .exceptions import InvalidContextError
 from .model import FriendMsg, GroupMsg
-from .util import file_to_base64
 
 
 def Text(text: str, at=False):
@@ -30,7 +30,7 @@ def Text(text: str, at=False):
                 ctx = v
                 break
     if ctx is None:
-        raise InvalidContextError('经支持群消息和好友消息接收函数内调用')
+        raise InvalidContextError('仅支持群消息和好友消息接收函数内调用')
 
     if hasattr(ctx, '_host') and hasattr(ctx, '_port'):
         action = Action(ctx.CurrentQQ, port=ctx._port, host=ctx._host)
@@ -56,7 +56,7 @@ def Picture(pic_url='', pic_base64='', pic_path='', pic_md5='', text=''):
     :param pic_url: 图片链接
     :param pic_base64: 图片base64编码
     :param pic_path: 图片文件路径
-    :param pic_md5: 已发送图片的MD5
+    :param pic_md5: 已发送图片的MD5, 如果是发给群聊，可以传入图片MD5列表
     :param text: 包含的文字消息
 
     ``pic_url, pic_base64, pic_path必须给定一项``
@@ -75,7 +75,7 @@ def Picture(pic_url='', pic_base64='', pic_path='', pic_md5='', text=''):
                 ctx = v
                 break
     if ctx is None:
-        raise InvalidContextError('经支持群消息和好友消息接收函数内调用')
+        raise InvalidContextError('仅支持群消息和好友消息接收函数内调用')
 
     if hasattr(ctx, '_host') and hasattr(ctx, '_port'):
         action = Action(ctx.CurrentQQ, port=ctx._port, host=ctx._host)
@@ -95,7 +95,7 @@ def Picture(pic_url='', pic_base64='', pic_path='', pic_md5='', text=''):
                 ctx.FromGroupId, content=text, picBase64Buf=file_to_base64(pic_path)
             )
         elif pic_md5:
-            return action.sendGroupPic(ctx.FromGroupId, content=text, fileMd5=pic_md5)
+            return action.sendGroupPic(ctx.FromGroupId, content=text, picMd5s=pic_md5)
 
     if isinstance(ctx, FriendMsg):
         if pic_url:
@@ -163,7 +163,7 @@ def Voice(voice_url='', voice_base64='', voice_path=''):
                 ctx = v
                 break
     if ctx is None:
-        raise InvalidContextError('经支持群消息和好友消息接收函数内调用')
+        raise InvalidContextError('仅支持群消息和好友消息接收函数内调用')
 
     if hasattr(ctx, '_host') and hasattr(ctx, '_port'):
         action = Action(ctx.CurrentQQ, port=ctx._port, host=ctx._host)
